@@ -7,6 +7,6 @@ from pyg_cell._acell import acell, acell_load, acell_func, acell_go
 from pyg_cell._db_cell import db_cell, db_load, db_save, get_cell, get_data, load_cell, load_data, cell_push, cell_pull
 from pyg_cell._periodic_cell import periodic_cell
 from pyg_cell._latest_cell  import latest_cell
-from pyg_cell._cache import db_cache, cell_cache
+from pyg_cell._cache import db_cache, cell_cache, cell_cache_, db_cache_
 from pyg_cell._tree import cell_tree
     
\ No newline at end of file
