@@ -1,4 +1,4 @@
-from pyg_base import is_date, ulist, logger, as_list, get_cache, Dict, dictable
+from pyg_base import is_date, ulist, logger, is_str, as_list, get_cache, Dict, dictable
 from pyg_encoders import cell_root, root_path, pd_read_parquet, pickle_load, pd_read_csv, dictable_decode
 from pyg_npy import pd_read_npy
 from pyg_cell._types import _get_mode, _get_qq, DBS, QQ
@@ -14,7 +14,11 @@ _readers = dict(parquet = pd_read_parquet,
                 npy = pd_read_npy, 
                 csv = pd_read_csv,
                 dictable = dictable_decode)
-
+try:
+    from pyg_sql import sql_loads
+    _readers['sql'] = sql_loads
+except Exception:
+    pass
 
 _deleted = 'deleted'
 _id = '_id'
@@ -132,6 +136,14 @@ def _load_asof(table, kwargs, deleted, qq = None):
             else:
                 return history[0]
 
+import datetime
+def _is_primitive(value):
+    if isinstance(value, (tuple, list)):
+        return min([_is_primitive(v) for v in value], default = True)
+    elif isinstance(value, dict):
+        return min([_is_primitive(v) for v in value.values()], default = True)
+    else:
+        return value is None or isinstance(value, (bool, str, int, float, datetime.datetime, datetime.date, partial))
 
 class db_cell(cell):
     """
@@ -190,7 +202,10 @@ class db_cell(cell):
     def __init__(self, function = None, output = None, db = None, **kwargs):
         if db is not None:
             if not isinstance(db, partial):
-                raise ValueError('db must be a partial of a function like mongo_table initializing a mongo cursor')
+                raise ValueError('type of db is: %s while db must be a *partial* of a function like mongo_table initializing a mongo cursor' % type(db))
+            non_primitives = {key : value for key, value in db.keywords.items() if not _is_primitive(value)}
+            if len(non_primitives):
+                raise ValueError('partial construction of cell must be from primitive paramters. but these are not: %s'%non_primitives)
             super(db_cell, self).__init__(function = function, output = output, db = db, **kwargs)
         else:
             self[_db] = None
@@ -223,7 +238,9 @@ class db_cell(cell):
         if self.get(_db) is None:
             return super(db_cell, self)._address
         db = self.db()
-        return db.address + tuple([(key, self.get(key)) for key in db._pk])
+        db_address = db.address
+        db_dict = dict(db_address)
+        return db_address + tuple([(key, self.get(key)) for key in db._pk if key not in db_dict])
 
 
     def _clear(self):
@@ -327,10 +344,12 @@ class db_cell(cell):
             return self
         if address not in graph: # we load from the database
             if is_date(mode):
-                graph[address] = _load_asof(db, kwargs, deleted = mode)
+                doc = _load_asof(db, kwargs, deleted = mode)
+                graph[doc._address] = doc
             else:
                 try:
-                    graph[address] = _load_asof(table = db, kwargs = kwargs, deleted = False, qq = None)
+                    doc = _load_asof(table = db, kwargs = kwargs, deleted = False, qq = None)
+                    graph[doc._address] = doc
                 except Exception:
                     if mode in (1, True):
                         return self.load_output()
@@ -369,6 +388,12 @@ class db_cell(cell):
                 filename = path[:-n] + '/%s.%s'%(output, suffix)            
                 if os.path.exists(filename):
                     self[output] = reader(filename)
+                elif suffix == 'sql' and is_str(self.writer) and self.writer.endswith('sql'):
+                    try:
+                        filename = path[:-n] + '/%s'%(output)            
+                        self[output] = reader(filename)
+                    except Exception:
+                        pass
         return self
 
     def push(self, go = 1):        
@@ -514,8 +539,11 @@ def _get_cell(table = None, db = None, url = None, server = None, deleted = None
         address = t.address + kwargs_address
         if _from_memory and deleted in (None, False): # we want the standard cell
             if address not in GRAPH:
-                GRAPH[address] = _load_asof(t, kwargs, deleted, qq)
-            return GRAPH[address]
+                doc = _load_asof(t, kwargs, deleted, qq)
+                GRAPH[doc._address] = doc
+                return doc
+            else:
+                return GRAPH[address]
         else:
             return _load_asof(t, kwargs, deleted, qq) # must not overwrite live version. User wants a specific deleted version
     else:
